function [c,w_min]=linprop(genmat)
% [C,WMIN] = LINPROP(G) Compute all codewords for G and find the minimum weight.
%   Use the generator matrix G or a default generator matrix in case that
%   G is empty to list all codewords of a linear code.
%
% Inspired by problem 6.2 from Proakis et.al.

    if nargin == 0 || isempty(genmat)
        % Define G, the default generator matrix.
        genmat = [ 1 0 0 1 1 1 0 1 1 1 ;
                1 1 1 0 0 0 1 1 1 0 ;
                0 1 1 0 1 1 0 1 0 1 ;
                1 1 0 1 1 1 1 0 0 1 ];
    end
    
    % Step 1: Determine the size of the generator matrix. The number of
    % columns will be `n`, the total length of the code. The number of rows
    % will be `k`, the number of information bits in the code.
    [k, n] = ...;
    % Check that `genmat` has the correct properties
    if ...
        error('linprop: G must be a generator matrix in standard form');
    end

    % Step 2: Generate `u`, a matrix containing all information sequences
    % as rows. 
    % Determine the amout of all binary plaintext words given that the
    % plaintex word length is `k` bits.
    word_count = ...;
    % Allocate space for all code words
    u = ...;
    % Loop over all `word_count` integers starting at zero 
    for i=...
        % Use the standard Matlab function `decbinvec()` to convert `i`
        % into a sequence of 0s and 1s of length exactly `k`
        u(...,:) = ...;
    end
    % Now `u` shall contain representation of all binary sequences with
    % integer values ranging from 0 to `word_count`-1.
    
    % Step 3: Generate a matrix of all codewords using simple matrix
    % multiplication in arithmetic modulo 2.
    c = ...;
    
    % Step 4: Find the minimum code distance. Note that for linear code the
    % `d_min` is identical to `w_min`, the minimum weight of a non-zero
    % codeword.
    % Sum the number of 1s in every codeword ...
    num_ones = ...;
    % ... and select minimum out of it.
    w_min = ...;
end